summaryrefslogtreecommitdiffstats
path: root/kioslave
diff options
context:
space:
mode:
Diffstat (limited to 'kioslave')
-rw-r--r--kioslave/file/file.cc30
-rw-r--r--kioslave/ftp/ftp.cc6
-rw-r--r--kioslave/http/http.cc106
-rw-r--r--kioslave/http/http_cache_cleaner.cpp8
-rw-r--r--kioslave/http/kcookiejar/kcookiejar.cpp28
-rw-r--r--kioslave/http/kcookiejar/kcookiejar.h2
-rw-r--r--kioslave/http/kcookiejar/kcookiewin.cpp2
-rw-r--r--kioslave/http/kcookiejar/tests/kcookiejartest.cpp10
-rw-r--r--kioslave/iso/iso.cpp12
-rw-r--r--kioslave/iso/kiso.cpp2
-rw-r--r--kioslave/iso/kisofile.cpp4
11 files changed, 105 insertions, 105 deletions
diff --git a/kioslave/file/file.cc b/kioslave/file/file.cc
index 2deeb3535..496f761dd 100644
--- a/kioslave/file/file.cc
+++ b/kioslave/file/file.cc
@@ -379,7 +379,7 @@ void FileProtocol::put( const KURL& url, int _mode, bool _overwrite, bool _resum
kdDebug(7101) << "put(): " << dest_orig << ", mode=" << _mode << endl;
TQString dest_part( dest_orig );
- dest_part += TQString::fromLatin1(".part");
+ dest_part += TQString::tqfromLatin1(".part");
TQCString _dest_part( TQFile::encodeName(dest_part));
KDE_struct_stat buff_orig;
@@ -809,7 +809,7 @@ void FileProtocol::copy( const KURL &src, const KURL &dest,
ut.modtime = buff_src.st_mtime;
if ( ::utime( _dest.data(), &ut ) != 0 )
{
- kdWarning() << TQString(TQString::fromLatin1("Couldn't preserve access and modification time for\n%1").arg( dest.path() )) << endl;
+ kdWarning() << TQString(TQString::tqfromLatin1("Couldn't preserve access and modification time for\n%1").arg( dest.path() )) << endl;
}
processedSize( buff_src.st_size );
@@ -859,7 +859,7 @@ void FileProtocol::rename( const KURL &src, const KURL &dest,
error( KIO::ERR_ACCESS_DENIED, dest.path() );
}
else if (errno == EXDEV) {
- error( KIO::ERR_UNSUPPORTED_ACTION, TQString::fromLatin1("rename"));
+ error( KIO::ERR_UNSUPPORTED_ACTION, TQString::tqfromLatin1("rename"));
}
else if (errno == EROFS) { // The file is on a read-only filesystem
error( KIO::ERR_CANNOT_DELETE, src.path() );
@@ -964,8 +964,8 @@ TQString FileProtocol::getUserName( uid_t uid )
if ( !temp ) {
struct passwd *user = getpwuid( uid );
if ( user ) {
- usercache.insert( uid, new TQString(TQString::fromLatin1(user->pw_name)) );
- return TQString::fromLatin1( user->pw_name );
+ usercache.insert( uid, new TQString(TQString::tqfromLatin1(user->pw_name)) );
+ return TQString::tqfromLatin1( user->pw_name );
}
else
return TQString::number( uid );
@@ -981,8 +981,8 @@ TQString FileProtocol::getGroupName( gid_t gid )
if ( !temp ) {
struct group *grp = getgrgid( gid );
if ( grp ) {
- groupcache.insert( gid, new TQString(TQString::fromLatin1(grp->gr_name)) );
- return TQString::fromLatin1( grp->gr_name );
+ groupcache.insert( gid, new TQString(TQString::tqfromLatin1(grp->gr_name)) );
+ return TQString::tqfromLatin1( grp->gr_name );
}
else
return TQString::number( gid );
@@ -1116,7 +1116,7 @@ void FileProtocol::stat( const KURL & url )
*/
TQCString _path( TQFile::encodeName(url.path(-1)));
- TQString sDetails = metaData(TQString::fromLatin1("details"));
+ TQString sDetails = metaData(TQString::tqfromLatin1("details"));
int details = sDetails.isEmpty() ? 2 : sDetails.toInt();
kdDebug(7101) << "FileProtocol::stat details=" << details << endl;
@@ -1419,10 +1419,10 @@ void FileProtocol::mount( bool _ro, const char *_fstype, const TQString& _dev, c
bool fstype_empty = !_fstype || !*_fstype;
TQCString fstype = KProcess::quote(_fstype).latin1(); // good guess
TQCString readonly = _ro ? "-r" : "";
- TQString epath = TQString::fromLatin1(getenv("PATH"));
- TQString path = TQString::fromLatin1("/sbin:/bin");
+ TQString epath = TQString::tqfromLatin1(getenv("PATH"));
+ TQString path = TQString::tqfromLatin1("/sbin:/bin");
if(!epath.isEmpty())
- path += TQString::fromLatin1(":") + epath;
+ path += TQString::tqfromLatin1(":") + epath;
TQString mountProg = KGlobal::dirs()->findExe("mount", path);
if (mountProg.isEmpty()){
error( KIO::ERR_COULD_NOT_MOUNT, i18n("Could not find program \"mount\""));
@@ -1604,7 +1604,7 @@ void FileProtocol::unmount( const TQString& _point )
}
#else
TQString epath = getenv("PATH");
- TQString path = TQString::fromLatin1("/sbin:/bin");
+ TQString path = TQString::tqfromLatin1("/sbin:/bin");
if (!epath.isEmpty())
path += ":" + epath;
TQString umountProg = KGlobal::dirs()->findExe("umount", path);
@@ -1658,7 +1658,7 @@ void FileProtocol::unmount( const TQString& _point )
bool FileProtocol::pmount(const TQString &dev)
{
TQString epath = getenv("PATH");
- TQString path = TQString::fromLatin1("/sbin:/bin");
+ TQString path = TQString::tqfromLatin1("/sbin:/bin");
if (!epath.isEmpty())
path += ":" + epath;
TQString pmountProg = KGlobal::dirs()->findExe("pmount", path);
@@ -1700,7 +1700,7 @@ bool FileProtocol::pumount(const TQString &point)
if (dev.endsWith("/")) dev.truncate(dev.length()-1);
TQString epath = getenv("PATH");
- TQString path = TQString::fromLatin1("/sbin:/bin");
+ TQString path = TQString::tqfromLatin1("/sbin:/bin");
if (!epath.isEmpty())
path += ":" + epath;
TQString pumountProg = KGlobal::dirs()->findExe("pumount", path);
@@ -1774,7 +1774,7 @@ static bool isExtendedACL( acl_t acl )
static TQString aclAsString( acl_t acl )
{
char *aclString = acl_to_text( acl, 0 );
- TQString ret = TQString::fromLatin1( aclString );
+ TQString ret = TQString::tqfromLatin1( aclString );
acl_free( (void*)aclString );
return ret;
}
diff --git a/kioslave/ftp/ftp.cc b/kioslave/ftp/ftp.cc
index 07208fe77..a30710743 100644
--- a/kioslave/ftp/ftp.cc
+++ b/kioslave/ftp/ftp.cc
@@ -71,9 +71,9 @@
#endif
// JPF: a remark on coding style (2004-03-06):
-// Some calls to TQString::fromLatin1() were removed from the code. In most places
+// Some calls to TQString::tqfromLatin1() were removed from the code. In most places
// the KDE code relies on implicit creation of QStrings. Also Qt has a lot of
-// const char* overloads, so that using TQString::fromLatin1() can be ineffectient!
+// const char* overloads, so that using TQString::tqfromLatin1() can be ineffectient!
#define FTP_LOGIN "anonymous"
#define FTP_PASSWD "anonymous@"
@@ -968,7 +968,7 @@ int Ftp::ftpOpenEPRTDataConnection()
if (sin == NULL)
return ERR_INTERNAL;
- // TQString command = TQString::fromLatin1("eprt |%1|%2|%3|").arg(sin->ianaFamily())
+ // TQString command = TQString::tqfromLatin1("eprt |%1|%2|%3|").arg(sin->ianaFamily())
// .arg(sin->nodeName())
// .arg(sin->port());
TQCString command;
diff --git a/kioslave/http/http.cc b/kioslave/http/http.cc
index a1495d78b..f772950bb 100644
--- a/kioslave/http/http.cc
+++ b/kioslave/http/http.cc
@@ -607,7 +607,7 @@ void HTTPProtocol::stat(const KURL& url)
if ( m_protocol != "webdav" && m_protocol != "webdavs" )
{
- TQString statSide = metaData(TQString::fromLatin1("statSide"));
+ TQString statSide = metaData(TQString::tqfromLatin1("statSide"));
if ( statSide != "source" )
{
// When uploading we assume the file doesn't exit
@@ -1805,7 +1805,7 @@ bool HTTPProtocol::isOffline(const KURL &url)
TQDataStream stream(params, IO_WriteOnly);
- if ( url.host() == TQString::fromLatin1("localhost") || url.host() == TQString::fromLatin1("127.0.0.1") || url.host() == TQString::fromLatin1("::") ) {
+ if ( url.host() == TQString::tqfromLatin1("localhost") || url.host() == TQString::tqfromLatin1("127.0.0.1") || url.host() == TQString::tqfromLatin1("::") ) {
return false;
}
if ( dcopClient()->call( "kded", "networkstatus", "status()",
@@ -2786,7 +2786,7 @@ try_again:
// by assuming that they will be sending html.
kdDebug(7113) << "(" << m_pid << ") HTTPPreadHeader: HEAD -> returned "
<< "mimetype: " << DEFAULT_MIME_TYPE << endl;
- mimeType(TQString::fromLatin1(DEFAULT_MIME_TYPE));
+ mimeType(TQString::tqfromLatin1(DEFAULT_MIME_TYPE));
return true;
}
@@ -2847,7 +2847,7 @@ try_again:
// Store the the headers so they can be passed to the
// calling application later
- m_responseHeader << TQString::fromLatin1(buf);
+ m_responseHeader << TQString::tqfromLatin1(buf);
if ((strncasecmp(buf, "HTTP/", 5) == 0) ||
(strncasecmp(buf, "ICY ", 4) == 0)) // Shoutcast support
@@ -3030,7 +3030,7 @@ try_again:
// Keep Alive
else if (strncasecmp(buf, "Keep-Alive:", 11) == 0) {
TQStringList options = TQStringList::split(',',
- TQString::fromLatin1(trimLead(buf+11)));
+ TQString::tqfromLatin1(trimLead(buf+11)));
for(TQStringList::ConstIterator it = options.begin();
it != options.end();
it++)
@@ -3046,7 +3046,7 @@ try_again:
// Cache control
else if (strncasecmp(buf, "Cache-Control:", 14) == 0) {
TQStringList cacheControls = TQStringList::split(',',
- TQString::fromLatin1(trimLead(buf+14)));
+ TQString::tqfromLatin1(trimLead(buf+14)));
for(TQStringList::ConstIterator it = cacheControls.begin();
it != cacheControls.end();
it++)
@@ -3081,7 +3081,7 @@ try_again:
else if (strncasecmp(buf, "Content-location:", 17) == 0) {
setMetaData ("content-location",
- TQString::fromLatin1(trimLead(buf+17)).stripWhiteSpace());
+ TQString::tqfromLatin1(trimLead(buf+17)).stripWhiteSpace());
}
// what type of data do we have?
@@ -3093,7 +3093,7 @@ try_again:
while ( *pos && *pos != ';' ) pos++;
// Assign the mime-type.
- m_strMimeType = TQString::fromLatin1(start, pos-start).stripWhiteSpace().lower();
+ m_strMimeType = TQString::tqfromLatin1(start, pos-start).stripWhiteSpace().lower();
kdDebug(7113) << "(" << m_pid << ") Content-type: " << m_strMimeType << endl;
// If we still have text, then it means we have a mime-type with a
@@ -3108,8 +3108,8 @@ try_again:
if (*pos)
{
- mediaAttribute = TQString::fromLatin1(start, pos-start).stripWhiteSpace().lower();
- mediaValue = TQString::fromLatin1(pos+1, end-pos-1).stripWhiteSpace();
+ mediaAttribute = TQString::tqfromLatin1(start, pos-start).stripWhiteSpace().lower();
+ mediaValue = TQString::tqfromLatin1(pos+1, end-pos-1).stripWhiteSpace();
pos = end;
if (mediaValue.length() &&
(mediaValue[0] == '"') &&
@@ -3153,7 +3153,7 @@ try_again:
// Cache management
else if (strncasecmp(buf, "Last-Modified:", 14) == 0) {
- m_request.lastModified = (TQString::fromLatin1(trimLead(buf+14))).stripWhiteSpace();
+ m_request.lastModified = (TQString::tqfromLatin1(trimLead(buf+14))).stripWhiteSpace();
}
// whoops.. we received a warning
@@ -3177,7 +3177,7 @@ try_again:
// The deprecated Refresh Response
else if (strncasecmp(buf,"Refresh:", 8) == 0) {
mayCache = false; // Do not cache page as it defeats purpose of Refresh tag!
- setMetaData( "http-refresh", TQString::fromLatin1(trimLead(buf+8)).stripWhiteSpace() );
+ setMetaData( "http-refresh", TQString::tqfromLatin1(trimLead(buf+8)).stripWhiteSpace() );
}
// In fact we should do redirection only if we got redirection code
@@ -3254,7 +3254,7 @@ try_again:
dispositionBuf--;
if ( dispositionBuf > bufStart )
- dispositionFilename = TQString::fromLatin1( bufStart, dispositionBuf-bufStart );
+ dispositionFilename = TQString::tqfromLatin1( bufStart, dispositionBuf-bufStart );
break;
}
@@ -3267,7 +3267,7 @@ try_again:
dispositionBuf++;
if ( dispositionBuf > bufStart )
- dispositionType = TQString::fromLatin1( bufStart, dispositionBuf-bufStart ).stripWhiteSpace();
+ dispositionType = TQString::tqfromLatin1( bufStart, dispositionBuf-bufStart ).stripWhiteSpace();
while ( *dispositionBuf == ';' || *dispositionBuf == ' ' )
dispositionBuf++;
@@ -3288,7 +3288,7 @@ try_again:
}
}
else if(strncasecmp(buf, "Content-Language:", 17) == 0) {
- TQString language = TQString::fromLatin1(trimLead(buf+17)).stripWhiteSpace();
+ TQString language = TQString::tqfromLatin1(trimLead(buf+17)).stripWhiteSpace();
if (!language.isEmpty())
setMetaData("content-language", language);
}
@@ -3381,17 +3381,17 @@ try_again:
// md5 signature
else if (strncasecmp(buf, "Content-MD5:", 12) == 0) {
- m_sContentMD5 = TQString::fromLatin1(trimLead(buf + 12));
+ m_sContentMD5 = TQString::tqfromLatin1(trimLead(buf + 12));
}
// *** Responses to the HTTP OPTIONS method follow
// WebDAV capabilities
else if (strncasecmp(buf, "DAV:", 4) == 0) {
if (m_davCapabilities.isEmpty()) {
- m_davCapabilities << TQString::fromLatin1(trimLead(buf + 4));
+ m_davCapabilities << TQString::tqfromLatin1(trimLead(buf + 4));
}
else {
- m_davCapabilities << TQString::fromLatin1(trimLead(buf + 4));
+ m_davCapabilities << TQString::tqfromLatin1(trimLead(buf + 4));
}
}
// *** Responses to the HTTP OPTIONS method finished
@@ -3667,14 +3667,14 @@ try_again:
if (m_strMimeType == "application/x-tar")
{
m_qContentEncodings.remove(m_qContentEncodings.fromLast());
- m_strMimeType = TQString::fromLatin1("application/x-tgz");
+ m_strMimeType = TQString::tqfromLatin1("application/x-tgz");
}
else if (m_strMimeType == "application/postscript")
{
// LEONB: Adding another exception for psgz files.
// Could we use the mimelnk files instead of hardcoding all this?
m_qContentEncodings.remove(m_qContentEncodings.fromLast());
- m_strMimeType = TQString::fromLatin1("application/x-gzpostscript");
+ m_strMimeType = TQString::tqfromLatin1("application/x-gzpostscript");
}
else if ( m_request.allowCompressedPage &&
m_strMimeType != "application/x-tgz" &&
@@ -3683,7 +3683,7 @@ try_again:
m_request.url.path().right(6) == ".ps.gz" )
{
m_qContentEncodings.remove(m_qContentEncodings.fromLast());
- m_strMimeType = TQString::fromLatin1("application/x-gzpostscript");
+ m_strMimeType = TQString::tqfromLatin1("application/x-gzpostscript");
}
else if ( (m_request.allowCompressedPage &&
m_strMimeType == "text/html")
@@ -3700,7 +3700,7 @@ try_again:
else
{
m_qContentEncodings.remove(m_qContentEncodings.fromLast());
- m_strMimeType = TQString::fromLatin1("application/x-gzip");
+ m_strMimeType = TQString::tqfromLatin1("application/x-gzip");
}
}
@@ -3713,34 +3713,34 @@ try_again:
if (m_qContentEncodings.last() == "bzip2")
{
m_qContentEncodings.remove(m_qContentEncodings.fromLast());
- m_strMimeType = TQString::fromLatin1("application/x-bzip2");
+ m_strMimeType = TQString::tqfromLatin1("application/x-bzip2");
}
// Convert some common mimetypes to standard KDE mimetypes
if (m_strMimeType == "application/x-targz")
- m_strMimeType = TQString::fromLatin1("application/x-tgz");
+ m_strMimeType = TQString::tqfromLatin1("application/x-tgz");
else if (m_strMimeType == "application/zip")
- m_strMimeType = TQString::fromLatin1("application/x-zip");
+ m_strMimeType = TQString::tqfromLatin1("application/x-zip");
else if (m_strMimeType == "image/x-png")
- m_strMimeType = TQString::fromLatin1("image/png");
+ m_strMimeType = TQString::tqfromLatin1("image/png");
else if (m_strMimeType == "image/bmp")
- m_strMimeType = TQString::fromLatin1("image/x-bmp");
+ m_strMimeType = TQString::tqfromLatin1("image/x-bmp");
else if (m_strMimeType == "audio/mpeg" || m_strMimeType == "audio/x-mpeg" || m_strMimeType == "audio/mp3")
- m_strMimeType = TQString::fromLatin1("audio/x-mp3");
+ m_strMimeType = TQString::tqfromLatin1("audio/x-mp3");
else if (m_strMimeType == "audio/microsoft-wave")
- m_strMimeType = TQString::fromLatin1("audio/x-wav");
+ m_strMimeType = TQString::tqfromLatin1("audio/x-wav");
else if (m_strMimeType == "audio/midi")
- m_strMimeType = TQString::fromLatin1("audio/x-midi");
+ m_strMimeType = TQString::tqfromLatin1("audio/x-midi");
else if (m_strMimeType == "image/x-xpixmap")
- m_strMimeType = TQString::fromLatin1("image/x-xpm");
+ m_strMimeType = TQString::tqfromLatin1("image/x-xpm");
else if (m_strMimeType == "application/rtf")
- m_strMimeType = TQString::fromLatin1("text/rtf");
+ m_strMimeType = TQString::tqfromLatin1("text/rtf");
// Crypto ones....
else if (m_strMimeType == "application/pkix-cert" ||
m_strMimeType == "application/binary-certificate")
{
- m_strMimeType = TQString::fromLatin1("application/x-x509-ca-cert");
+ m_strMimeType = TQString::tqfromLatin1("application/x-x509-ca-cert");
}
// Prefer application/x-tgz or x-gzpostscript over application/x-gzip.
@@ -3748,9 +3748,9 @@ try_again:
{
if ((m_request.url.path().right(7) == ".tar.gz") ||
(m_request.url.path().right(4) == ".tar"))
- m_strMimeType = TQString::fromLatin1("application/x-tgz");
+ m_strMimeType = TQString::tqfromLatin1("application/x-tgz");
if ((m_request.url.path().right(6) == ".ps.gz"))
- m_strMimeType = TQString::fromLatin1("application/x-gzpostscript");
+ m_strMimeType = TQString::tqfromLatin1("application/x-gzpostscript");
}
// Some webservers say "text/plain" when they mean "application/x-bzip2"
@@ -3758,15 +3758,15 @@ try_again:
{
TQString ext = m_request.url.path().right(4).upper();
if (ext == ".BZ2")
- m_strMimeType = TQString::fromLatin1("application/x-bzip2");
+ m_strMimeType = TQString::tqfromLatin1("application/x-bzip2");
else if (ext == ".PEM")
- m_strMimeType = TQString::fromLatin1("application/x-x509-ca-cert");
+ m_strMimeType = TQString::tqfromLatin1("application/x-x509-ca-cert");
else if (ext == ".SWF")
- m_strMimeType = TQString::fromLatin1("application/x-shockwave-flash");
+ m_strMimeType = TQString::tqfromLatin1("application/x-shockwave-flash");
else if (ext == ".PLS")
- m_strMimeType = TQString::fromLatin1("audio/x-scpls");
+ m_strMimeType = TQString::tqfromLatin1("audio/x-scpls");
else if (ext == ".WMV")
- m_strMimeType = TQString::fromLatin1("video/x-ms-wmv");
+ m_strMimeType = TQString::tqfromLatin1("video/x-ms-wmv");
}
#if 0
@@ -3871,11 +3871,11 @@ void HTTPProtocol::addEncoding(TQString encoding, TQStringList &encs)
//if ( m_cmd != CMD_COPY )
m_iSize = NO_SIZE;
} else if ((encoding == "x-gzip") || (encoding == "gzip")) {
- encs.append(TQString::fromLatin1("gzip"));
+ encs.append(TQString::tqfromLatin1("gzip"));
} else if ((encoding == "x-bzip2") || (encoding == "bzip2")) {
- encs.append(TQString::fromLatin1("bzip2")); // Not yet supported!
+ encs.append(TQString::tqfromLatin1("bzip2")); // Not yet supported!
} else if ((encoding == "x-deflate") || (encoding == "deflate")) {
- encs.append(TQString::fromLatin1("deflate"));
+ encs.append(TQString::tqfromLatin1("deflate"));
} else {
kdDebug(7113) << "(" << m_pid << ") Unknown encoding encountered. "
<< "Please write code. Encoding = \"" << encoding
@@ -4270,7 +4270,7 @@ void HTTPProtocol::slotData(const TQByteArray &_d)
if ( m_strMimeType.isEmpty() )
{
- m_strMimeType = TQString::fromLatin1( DEFAULT_MIME_TYPE );
+ m_strMimeType = TQString::tqfromLatin1( DEFAULT_MIME_TYPE );
kdDebug(7113) << "(" << m_pid << ") Using default mimetype: "
<< m_strMimeType << endl;
}
@@ -4711,7 +4711,7 @@ FILE* HTTPProtocol::checkCacheEntry( bool readWrite)
TQCString u = m_request.url.url().latin1();
for(int i = u.length(); i--;)
{
- hash = (hash * 12211 + static_cast<const char>(u.at(i))) % 2147483563;
+ hash = (hash * 12211 + static_cast<const char>(u.tqat(i))) % 2147483563;
}
TQString hashString;
@@ -4739,7 +4739,7 @@ FILE* HTTPProtocol::checkCacheEntry( bool readWrite)
ok = false;
time_t date;
- time_t currentDate = time(0);
+ time_t tqcurrentDate = time(0);
// URL
if (ok && (!fgets(buffer, 400, fs)))
@@ -4762,10 +4762,10 @@ FILE* HTTPProtocol::checkCacheEntry( bool readWrite)
{
date = (time_t) strtoul(buffer, 0, 10);
m_request.creationDate = date;
- if (m_maxCacheAge && (difftime(currentDate, date) > m_maxCacheAge))
+ if (m_maxCacheAge && (difftime(tqcurrentDate, date) > m_maxCacheAge))
{
m_request.bMustRevalidate = true;
- m_request.expireDate = currentDate;
+ m_request.expireDate = tqcurrentDate;
}
}
@@ -4779,14 +4779,14 @@ FILE* HTTPProtocol::checkCacheEntry( bool readWrite)
{
date = (time_t) strtoul(buffer, 0, 10);
// After the expire date we need to revalidate.
- if (!date || difftime(currentDate, date) >= 0)
+ if (!date || difftime(tqcurrentDate, date) >= 0)
m_request.bMustRevalidate = true;
m_request.expireDate = date;
}
else if (m_request.cache == CC_Refresh)
{
m_request.bMustRevalidate = true;
- m_request.expireDate = currentDate;
+ m_request.expireDate = tqcurrentDate;
}
}
@@ -5135,12 +5135,12 @@ void HTTPProtocol::configAuth( char *p, bool isForProxy )
if( isForProxy )
{
ProxyAuthentication = f;
- m_strProxyAuthorization = TQString::fromLatin1( strAuth );
+ m_strProxyAuthorization = TQString::tqfromLatin1( strAuth );
}
else
{
Authentication = f;
- m_strAuthorization = TQString::fromLatin1( strAuth );
+ m_strAuthorization = TQString::tqfromLatin1( strAuth );
}
}
@@ -5943,7 +5943,7 @@ TQString HTTPProtocol::createDigestAuth ( bool isForProxy )
for (int i = 0; i < count; i++ )
{
- KURL u ( info.digestURI.at(i) );
+ KURL u ( info.digestURI.tqat(i) );
send &= (m_request.url.protocol().lower() == u.protocol().lower());
send &= (m_request.hostname.lower() == u.host().lower());
diff --git a/kioslave/http/http_cache_cleaner.cpp b/kioslave/http/http_cache_cleaner.cpp
index 02a07c712..cc17d9729 100644
--- a/kioslave/http/http_cache_cleaner.cpp
+++ b/kioslave/http/http_cache_cleaner.cpp
@@ -44,7 +44,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdebug.h>
-time_t currentDate;
+time_t tqcurrentDate;
int m_maxCacheAge;
int m_maxCacheSize;
@@ -109,7 +109,7 @@ FileInfo *readEntry( const TQString &filename)
if (ok)
{
creationDate = (time_t) strtoul(buffer, 0, 10);
- age = (int) difftime(currentDate, creationDate);
+ age = (int) difftime(tqcurrentDate, creationDate);
if ( m_maxCacheAge && ( age > m_maxCacheAge))
{
ok = false; // Expired
@@ -125,7 +125,7 @@ FileInfo *readEntry( const TQString &filename)
#if 0
time_t expireDate;
expireDate = (time_t) strtoul(buffer, 0, 10);
- if (expireDate && (expireDate < currentDate))
+ if (expireDate && (expireDate < tqcurrentDate))
ok = false; // Expired
#endif
}
@@ -213,7 +213,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
}
}
- currentDate = time(0);
+ tqcurrentDate = time(0);
m_maxCacheAge = KProtocolManager::maxCacheAge();
m_maxCacheSize = KProtocolManager::maxCacheSize();
diff --git a/kioslave/http/kcookiejar/kcookiejar.h b/kioslave/http/kcookiejar/kcookiejar.h
index eb64485ea..6d5d9f2e5 100644
--- a/kioslave/http/kcookiejar/kcookiejar.h
+++ b/kioslave/http/kcookiejar/kcookiejar.h
@@ -89,7 +89,7 @@ public:
time_t expireDate(void) { return mExpireDate; }
int protocolVersion(void) { return mProtocolVersion; }
bool isSecure(void) { return mSecure; }
- bool isExpired(time_t currentDate);
+ bool isExpired(time_t tqcurrentDate);
bool isCrossDomain(void) { return mCrossDomain; }
bool isHttpOnly(void) { return mHttpOnly; }
bool hasExplicitPath(void) { return mExplicitPath; }
diff --git a/kioslave/http/kcookiejar/kcookiewin.cpp b/kioslave/http/kcookiejar/kcookiewin.cpp
index e59533e23..0ee01d9f0 100644
--- a/kioslave/http/kcookiejar/kcookiewin.cpp
+++ b/kioslave/http/kcookiejar/kcookiewin.cpp
@@ -40,7 +40,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqaccel.h>
#include <tqlabel.h>
#include <tqwidget.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqgroupbox.h>
#include <tqdatetime.h>
#include <tqmessagebox.h>
diff --git a/kioslave/http/kcookiejar/tests/kcookiejartest.cpp b/kioslave/http/kcookiejar/tests/kcookiejartest.cpp
index 0ad238ab7..1ce1c4d8f 100644
--- a/kioslave/http/kcookiejar/tests/kcookiejartest.cpp
+++ b/kioslave/http/kcookiejar/tests/kcookiejartest.cpp
@@ -72,12 +72,12 @@ static void popArg(TQString &command, TQCString & line)
int i = line.find(' ');
if (i != -1)
{
- command = TQString::fromLatin1(line.left(i));
+ command = TQString::tqfromLatin1(line.left(i));
line = line.mid(i+1);
}
else
{
- command = TQString::fromLatin1(line);
+ command = TQString::tqfromLatin1(line);
line = 0;
}
}
@@ -158,7 +158,7 @@ static void processCheck(TQCString &line)
if (url.isEmpty())
FAIL(TQString("Missing URL"));
- TQString expectedCookies = TQString::fromLatin1(line);
+ TQString expectedCookies = TQString::tqfromLatin1(line);
TQString cookies = jar->findCookies(urlStr, false, 0, 0).stripWhiteSpace();
if (cookies != expectedCookies)
@@ -246,8 +246,8 @@ int main(int argc, char *argv[])
TQCString arg2;
TQString result;
- lastYear = new TQCString(TQString("Fri, 04-May-%1 01:00:00 GMT").arg(TQDate::currentDate().year()-1).utf8());
- nextYear = new TQCString(TQString(" expires=Fri, 04-May-%1 01:00:00 GMT").arg(TQDate::currentDate().year()+1).utf8());
+ lastYear = new TQCString(TQString("Fri, 04-May-%1 01:00:00 GMT").arg(TQDate::tqcurrentDate().year()-1).utf8());
+ nextYear = new TQCString(TQString(" expires=Fri, 04-May-%1 01:00:00 GMT").arg(TQDate::tqcurrentDate().year()+1).utf8());
KAboutData about("kcookietest", "kcookietest", "1.0", description, KAboutData::License_GPL, "(C) 2004 Waldo Bastian");
KCmdLineArgs::init( argc, argv, &about);
diff --git a/kioslave/iso/iso.cpp b/kioslave/iso/iso.cpp
index 586513956..9e5691654 100644
--- a/kioslave/iso/iso.cpp
+++ b/kioslave/iso/iso.cpp
@@ -150,7 +150,7 @@ bool kio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int star
path.truncate( len - 1 );
}
else
- path = TQString::fromLatin1("/");
+ path = TQString::tqfromLatin1("/");
kdDebug() << "Found. isoFile=" << isoFile << " path=" << path << endl;
break;
}
@@ -259,10 +259,10 @@ void kio_isoProtocol::listDir( const KURL & url )
if ( path.isEmpty() )
{
- KURL redir( TQString::fromLatin1( "iso:/") );
+ KURL redir( TQString::tqfromLatin1( "iso:/") );
kdDebug() << "url.path()==" << url.path() << endl;
if (url.hasRef()) redir.setRef(url.htmlRef());
- redir.setPath( url.path() + TQString::fromLatin1("/") );
+ redir.setPath( url.path() + TQString::tqfromLatin1("/") );
kdDebug() << "kio_isoProtocol::listDir: redirection " << redir.url() << endl;
redirection( redir );
finished();
@@ -356,7 +356,7 @@ void kio_isoProtocol::stat( const KURL & url )
const KArchiveEntry* isoEntry;
if ( path.isEmpty() )
{
- path = TQString::fromLatin1( "/" );
+ path = TQString::tqfromLatin1( "/" );
isoEntry = root;
} else {
isoEntry = root->entry( path );
@@ -407,8 +407,8 @@ void kio_isoProtocol::getFile( const KIsoFile *isoFileEntry, const TQString &pat
ptrblock_bytes = (nblocks+1) * 4;
pointer_block=isoFileEntry->data( hdr->header_size << 2, ptrblock_bytes );
if (pointer_block.size() == ptrblock_bytes &&
- inbuf.resize(block_size2) &&
- outbuf.resize(block_size)) {
+ inbuf.tqresize(block_size2) &&
+ outbuf.tqresize(block_size)) {
pptr = pointer_block.data();
} else {
diff --git a/kioslave/iso/kiso.cpp b/kioslave/iso/kiso.cpp
index 47f71511d..7b682a783 100644
--- a/kioslave/iso/kiso.cpp
+++ b/kioslave/iso/kiso.cpp
@@ -192,7 +192,7 @@ static int readf(char *buf, int start, int len,void *udata) {
TQIODevice* dev = ( static_cast<KIso*> (udata) )->device();
- if (dev->at(start<<11)) {
+ if (dev->tqat(start<<11)) {
if ((dev->readBlock(buf, len<<11)) != -1) return (len);
}
kdDebug() << "KIso::ReadRequest failed start: " << start << " len: " << len << endl;
diff --git a/kioslave/iso/kisofile.cpp b/kioslave/iso/kisofile.cpp
index afac16b74..5235ea4a0 100644
--- a/kioslave/iso/kisofile.cpp
+++ b/kioslave/iso/kisofile.cpp
@@ -42,8 +42,8 @@ TQByteArray KIsoFile::data(long long pos, int count) const {
TQByteArray r;
int rlen;
- if ( archive()->device()->at(position()+pos) &&
- r.resize( ((pos+count) < size()) ? count : size()-pos) ) {
+ if ( archive()->device()->tqat(position()+pos) &&
+ r.tqresize( ((pos+count) < size()) ? count : size()-pos) ) {
rlen=archive()->device()->readBlock( r.data(), r.size() );
if (rlen ==- 1) r.resize(0);
else if (rlen != (int)r.size()) r.resize(rlen);
diff --git a/kioslave/http/kcookiejar/kcookiejar.cpp b/kioslave/http/kcookiejar/kcookiejar.cpp
index ec0a423a6..136fba0b1 100644
--- a/kioslave/http/kcookiejar/kcookiejar.cpp
+++ b/kioslave/http/kcookiejar/kcookiejar.cpp
@@ -84,12 +84,12 @@
#define READ_BUFFER_SIZE 8192
#define IP_ADDRESS_EXPRESSION "(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)"
// Note with respect to TQString::fromLatin1( )
// Cookies are stored as 8 bit data and passed to kio_http as
// latin1 regardless of their actual encoding.
// L1 is used to indicate latin1 constants
-#define L1(x) TQString::fromLatin1(x)
+#define L1(x) TQString::tqfromLatin1(x)
template class TQPtrList<KHttpCookie>;
template class TQPtrDict<KHttpCookieList>;
@@ -154,9 +154,9 @@ KHttpCookie::KHttpCookie(const TQString &_host,
//
// Checks if a cookie has been expired
//
-bool KHttpCookie::isExpired(time_t currentDate)
+bool KHttpCookie::isExpired(time_t tqcurrentDate)
{
- return (mExpireDate != 0) && (mExpireDate < currentDate);
+ return (mExpireDate != 0) && (mExpireDate < tqcurrentDate);
}
//
@@ -479,7 +479,7 @@ static const char * parseNameValue(const char *header,
// No '=' sign -> use string as the value, name is empty
// (behavior found in Mozilla and IE)
Name = "";
- Value = TQString::fromLatin1(header);
+ Value = TQString::tqfromLatin1(header);
Value.truncate( s - header );
Value = Value.stripWhiteSpace();
return (s);
@@ -516,12 +516,12 @@ static const char * parseNameValue(const char *header,
if ((*s=='\0') || (*s=='\n'))
{
// End of Name
- Value = TQString::fromLatin1(header);
+ Value = TQString::tqfromLatin1(header);
Value.truncate(s - header);
return (s);
}
}
- Value = TQString::fromLatin1(header);
+ Value = TQString::tqfromLatin1(header);
// *s == '\"';
if (keepQuotes)
Value.truncate( ++s - header );
@@ -542,7 +542,7 @@ static const char * parseNameValue(const char *header,
while ((*s != '\0') && (*s != ';') && (*s != '\n'))
s++;
// End of Name
- Value = TQString::fromLatin1(header);
+ Value = TQString::tqfromLatin1(header);
Value.truncate( s - header );
Value = Value.stripWhiteSpace();
}
@@ -618,7 +618,7 @@ void KCookieJar::extractDomains(const TQString &_fqdn,
return;
}
// Return numeric IPv4 addresses as is...
- if ((_fqdn.at(0) >= TQChar('0')) && (_fqdn.at(0) <= TQChar('9')))
+ if ((_fqdn.tqat(0) >= TQChar('0')) && (_fqdn.tqat(0) <= TQChar('9')))
{
if (_fqdn.find(TQRegExp(IP_ADDRESS_EXPRESSION)) > -1)
{
@@ -1457,11 +1457,11 @@ bool KCookieJar::loadCookies(const TQString &_filename)
if ((expDate == 0) || (expDate < curTime))
continue;
- KHttpCookie *cookie = new KHttpCookie(TQString::fromLatin1(host),
- TQString::fromLatin1(domain),
- TQString::fromLatin1(path),
- TQString::fromLatin1(name),
- TQString::fromLatin1(value),
+ KHttpCookie *cookie = new KHttpCookie(TQString::tqfromLatin1(host),
+ TQString::tqfromLatin1(domain),
+ TQString::tqfromLatin1(path),
+ TQString::tqfromLatin1(name),
+ TQString::tqfromLatin1(value),
expDate, protVer,
secure, httpOnly, explicitPath);
addCookie(cookie);
@@ -84,12 +84,12 @@
#define READ_BUFFER_SIZE 8192
#define IP_ADDRESS_EXPRESSION "(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)"
-// Note with respect to TQString::fromLatin1( )
+// Note with respect to TQString::tqfromLatin1( )
// Cookies are stored as 8 bit data and passed to kio_http as
// latin1 regardless of their actual encoding.